@@ -25,9 +25,10 @@ public class EESpecProfileTest {
 
     @Test
     public void testProfileTomcat() {
-        EESpecProfile profile = EESpecProfile.TOMCAT;
+        EESpecProfile profile = EESpecProfiles.TOMCAT;
 
-        assertEquals("jakarta.annotation", profile.convert("javax.annotation"));
+        assertEquals("jakarta.annotation.PostConstruct", profile.convert("javax.annotation.PostConstruct"));
+        assertEquals("jakarta.annotation.security.DeclareRoles", profile.convert("javax.annotation.security.DeclareRoles"));
         assertEquals("jakarta.ejb", profile.convert("javax.ejb"));
         assertEquals("jakarta.el", profile.convert("javax.el"));
         assertEquals("jakarta.mail", profile.convert("javax.mail"));
@@ -61,7 +62,7 @@ public class EESpecProfileTest {
         assertEquals("javax.xml.ws", profile.convert("javax.xml.ws"));
 
         // non EE javax packages
-        assertEquals("javax.annotation.processing", profile.convert("javax.annotation.processing"));
+        assertEquals("javax.annotation", profile.convert("javax.annotation"));
         assertEquals("javax.management", profile.convert("javax.management"));
         assertEquals("javax.security", profile.convert("javax.security"));
         assertEquals("javax.security.auth", profile.convert("javax.security.auth"));
@@ -71,14 +72,24 @@ public class EESpecProfileTest {
         assertEquals("javax.xml.namespace", profile.convert("javax.xml.namespace"));
         assertEquals("javax.xml.xpath.XPathConstants", profile.convert("javax.xml.xpath.XPathConstants"));
         assertEquals("javax.xml.XMLConstants", profile.convert("javax.xml.XMLConstants"));
+
+        // Findbugs JSR-305 packages and classes
+        assertEquals("javax.annotation.concurrent", profile.convert("javax.annotation.concurrent"));
+        assertEquals("javax.annotation.meta", profile.convert("javax.annotation.meta"));
+        assertEquals("javax.annotation.PropertyKey", profile.convert("javax.annotation.PropertyKey"));
+
+        // Annotation classes that overlap between earlier and later annotations implementations
+        assertEquals("javax.annotation.Nonnull", profile.convert("javax.annotation.Nonnull"));
+        assertEquals("javax.annotation.Nullable", profile.convert("javax.annotation.Nullable"));
     }
 
     @Test
     public void testProfileEE() {
-        EESpecProfile profile = EESpecProfile.EE;
+        EESpecProfile profile = EESpecProfiles.EE;
 
-        assertEquals("jakarta.activation", profile.convert("javax.activation"));
-        assertEquals("jakarta.annotation", profile.convert("javax.annotation"));
+        assertEquals("jakarta.activation.Generated", profile.convert("javax.activation.Generated"));
+        assertEquals("jakarta.annotation.PostConstruct", profile.convert("javax.annotation.PostConstruct"));
+        assertEquals("jakarta.annotation.security.DeclareRoles", profile.convert("javax.annotation.security.DeclareRoles"));
         assertEquals("jakarta.batch", profile.convert("javax.batch"));
         assertEquals("jakarta.decorator", profile.convert("javax.decorator"));
         assertEquals("jakarta.ejb", profile.convert("javax.ejb"));
@@ -103,8 +114,6 @@ public class EESpecProfileTest {
         assertEquals("jakarta.websocket", profile.convert("javax.websocket"));
         assertEquals("jakarta.ws.rs", profile.convert("javax.ws.rs"));
         assertEquals("jakarta.xml.bind", profile.convert("javax.xml.bind"));
-        assertEquals("jakarta.xml.registry", profile.convert("javax.xml.registry"));
-        assertEquals("jakarta.xml.rpc", profile.convert("javax.xml.rpc"));
         assertEquals("jakarta.xml.soap", profile.convert("javax.xml.soap"));
         assertEquals("jakarta.xml.ws", profile.convert("javax.xml.ws"));
 
@@ -117,6 +126,8 @@ public class EESpecProfileTest {
         assertEquals("javax.transaction.xa", profile.convert("javax.transaction.xa"));
         assertEquals("javax.xml.stream", profile.convert("javax.xml.stream"));
         assertEquals("javax.xml.namespace", profile.convert("javax.xml.namespace"));
+        assertEquals("javax.xml.registry", profile.convert("javax.xml.registry"));
+        assertEquals("javax.xml.rpc", profile.convert("javax.xml.rpc"));
         assertEquals("javax.xml.xpath.XPathConstants", profile.convert("javax.xml.xpath.XPathConstants"));
         assertEquals("javax.xml.XMLConstants", profile.convert("javax.xml.XMLConstants"));
     }
